from setuptools import setup

setup(name='random distributions',
      version='0.1',
      description='random distributions',
      author='Luz Orejel',
      author_email='deutschluz@gmail.com',
      packages=['random distributions'],
      zip_safe=False)
